# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._client_user_logout_request import ClientUserLogoutRequest
from ._client_user_logout_response_body import ClientUserLogoutResponseBody
from ._client_user_logout_response import ClientUserLogoutResponse
from ._find_idp_list_by_login_identifier_request import FindIdpListByLoginIdentifierRequest
from ._find_idp_list_by_login_identifier_shrink_request import FindIdpListByLoginIdentifierShrinkRequest
from ._find_idp_list_by_login_identifier_response_body import FindIdpListByLoginIdentifierResponseBody
from ._find_idp_list_by_login_identifier_response import FindIdpListByLoginIdentifierResponse
from ._get_login_token_request import GetLoginTokenRequest
from ._get_login_token_shrink_request import GetLoginTokenShrinkRequest
from ._get_login_token_response_body import GetLoginTokenResponseBody
from ._get_login_token_response import GetLoginTokenResponse
from ._get_sts_token_request import GetStsTokenRequest
from ._get_sts_token_response_body import GetStsTokenResponseBody
from ._get_sts_token_response import GetStsTokenResponse
from ._refresh_login_token_request import RefreshLoginTokenRequest
from ._refresh_login_token_response_body import RefreshLoginTokenResponseBody
from ._refresh_login_token_response import RefreshLoginTokenResponse
from ._find_idp_list_by_login_identifier_response_body import FindIdpListByLoginIdentifierResponseBodyIdpInfos
from ._find_idp_list_by_login_identifier_response_body import FindIdpListByLoginIdentifierResponseBodyOfficeSiteInfo
from ._find_idp_list_by_login_identifier_response_body import FindIdpListByLoginIdentifierResponseBodyTenantAliasInfo
from ._get_login_token_response_body import GetLoginTokenResponseBodyMfaTypeList
from ._get_login_token_response_body import GetLoginTokenResponseBodyPasswordStrategy
from ._get_login_token_response_body import GetLoginTokenResponseBodyRiskVerifyInfo
from ._get_login_token_response_body import GetLoginTokenResponseBodyTenantInfos
from ._get_sts_token_response_body import GetStsTokenResponseBodyStsTokenModel

__all__ = [
    ClientUserLogoutRequest,
    ClientUserLogoutResponseBody,
    ClientUserLogoutResponse,
    FindIdpListByLoginIdentifierRequest,
    FindIdpListByLoginIdentifierShrinkRequest,
    FindIdpListByLoginIdentifierResponseBody,
    FindIdpListByLoginIdentifierResponse,
    GetLoginTokenRequest,
    GetLoginTokenShrinkRequest,
    GetLoginTokenResponseBody,
    GetLoginTokenResponse,
    GetStsTokenRequest,
    GetStsTokenResponseBody,
    GetStsTokenResponse,
    RefreshLoginTokenRequest,
    RefreshLoginTokenResponseBody,
    RefreshLoginTokenResponse,
    FindIdpListByLoginIdentifierResponseBodyIdpInfos,
    FindIdpListByLoginIdentifierResponseBodyOfficeSiteInfo,
    FindIdpListByLoginIdentifierResponseBodyTenantAliasInfo,
    GetLoginTokenResponseBodyMfaTypeList,
    GetLoginTokenResponseBodyPasswordStrategy,
    GetLoginTokenResponseBodyRiskVerifyInfo,
    GetLoginTokenResponseBodyTenantInfos,
    GetStsTokenResponseBodyStsTokenModel
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Dict, List

from darabonba.model import DaraModel

class FindIdpListByLoginIdentifierRequest(DaraModel):
    def __init__(
        self,
        available_features: Dict[str, str] = None,
        client_channel: str = None,
        client_id: str = None,
        client_ip: str = None,
        client_os: str = None,
        client_version: str = None,
        login_identifier: str = None,
        support_types: List[str] = None,
        uuid: str = None,
    ):
        self.available_features = available_features
        self.client_channel = client_channel
        self.client_id = client_id
        self.client_ip = client_ip
        self.client_os = client_os
        self.client_version = client_version
        # This parameter is required.
        self.login_identifier = login_identifier
        self.support_types = support_types
        self.uuid = uuid

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.available_features is not None:
            result['AvailableFeatures'] = self.available_features

        if self.client_channel is not None:
            result['ClientChannel'] = self.client_channel

        if self.client_id is not None:
            result['ClientId'] = self.client_id

        if self.client_ip is not None:
            result['ClientIp'] = self.client_ip

        if self.client_os is not None:
            result['ClientOS'] = self.client_os

        if self.client_version is not None:
            result['ClientVersion'] = self.client_version

        if self.login_identifier is not None:
            result['LoginIdentifier'] = self.login_identifier

        if self.support_types is not None:
            result['SupportTypes'] = self.support_types

        if self.uuid is not None:
            result['Uuid'] = self.uuid

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AvailableFeatures') is not None:
            self.available_features = m.get('AvailableFeatures')

        if m.get('ClientChannel') is not None:
            self.client_channel = m.get('ClientChannel')

        if m.get('ClientId') is not None:
            self.client_id = m.get('ClientId')

        if m.get('ClientIp') is not None:
            self.client_ip = m.get('ClientIp')

        if m.get('ClientOS') is not None:
            self.client_os = m.get('ClientOS')

        if m.get('ClientVersion') is not None:
            self.client_version = m.get('ClientVersion')

        if m.get('LoginIdentifier') is not None:
            self.login_identifier = m.get('LoginIdentifier')

        if m.get('SupportTypes') is not None:
            self.support_types = m.get('SupportTypes')

        if m.get('Uuid') is not None:
            self.uuid = m.get('Uuid')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Dict

from alibabacloud_appstream_center20210220 import models as main_models
from darabonba.model import DaraModel

class GetLoginTokenResponseBody(DaraModel):
    def __init__(
        self,
        access_type: str = None,
        account_type: str = None,
        ad_domain: str = None,
        email: str = None,
        end_user_id: str = None,
        idp_id: str = None,
        industry: str = None,
        keep_alive_token: str = None,
        label: str = None,
        login_token: str = None,
        mfa_type_list: List[main_models.GetLoginTokenResponseBodyMfaTypeList] = None,
        next_stage: str = None,
        nick_name: str = None,
        office_sites: List[str] = None,
        password_strategy: main_models.GetLoginTokenResponseBodyPasswordStrategy = None,
        phone: str = None,
        props: Dict[str, str] = None,
        qr_code_png: str = None,
        reason: str = None,
        request_id: str = None,
        risk_verify_info: main_models.GetLoginTokenResponseBodyRiskVerifyInfo = None,
        secret: str = None,
        session_id: str = None,
        tenant_alias: str = None,
        tenant_id: int = None,
        tenant_infos: List[main_models.GetLoginTokenResponseBodyTenantInfos] = None,
        vpc_region_id: str = None,
        window_display_mode: str = None,
        wy_id: str = None,
    ):
        self.access_type = access_type
        self.account_type = account_type
        self.ad_domain = ad_domain
        self.email = email
        self.end_user_id = end_user_id
        self.idp_id = idp_id
        self.industry = industry
        self.keep_alive_token = keep_alive_token
        self.label = label
        self.login_token = login_token
        self.mfa_type_list = mfa_type_list
        self.next_stage = next_stage
        self.nick_name = nick_name
        self.office_sites = office_sites
        self.password_strategy = password_strategy
        self.phone = phone
        self.props = props
        self.qr_code_png = qr_code_png
        self.reason = reason
        self.request_id = request_id
        self.risk_verify_info = risk_verify_info
        self.secret = secret
        self.session_id = session_id
        self.tenant_alias = tenant_alias
        self.tenant_id = tenant_id
        self.tenant_infos = tenant_infos
        self.vpc_region_id = vpc_region_id
        self.window_display_mode = window_display_mode
        self.wy_id = wy_id

    def validate(self):
        if self.mfa_type_list:
            for v1 in self.mfa_type_list:
                 if v1:
                    v1.validate()
        if self.password_strategy:
            self.password_strategy.validate()
        if self.risk_verify_info:
            self.risk_verify_info.validate()
        if self.tenant_infos:
            for v1 in self.tenant_infos:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_type is not None:
            result['AccessType'] = self.access_type

        if self.account_type is not None:
            result['AccountType'] = self.account_type

        if self.ad_domain is not None:
            result['AdDomain'] = self.ad_domain

        if self.email is not None:
            result['Email'] = self.email

        if self.end_user_id is not None:
            result['EndUserId'] = self.end_user_id

        if self.idp_id is not None:
            result['IdpId'] = self.idp_id

        if self.industry is not None:
            result['Industry'] = self.industry

        if self.keep_alive_token is not None:
            result['KeepAliveToken'] = self.keep_alive_token

        if self.label is not None:
            result['Label'] = self.label

        if self.login_token is not None:
            result['LoginToken'] = self.login_token

        result['MfaTypeList'] = []
        if self.mfa_type_list is not None:
            for k1 in self.mfa_type_list:
                result['MfaTypeList'].append(k1.to_map() if k1 else None)

        if self.next_stage is not None:
            result['NextStage'] = self.next_stage

        if self.nick_name is not None:
            result['NickName'] = self.nick_name

        if self.office_sites is not None:
            result['OfficeSites'] = self.office_sites

        if self.password_strategy is not None:
            result['PasswordStrategy'] = self.password_strategy.to_map()

        if self.phone is not None:
            result['Phone'] = self.phone

        if self.props is not None:
            result['Props'] = self.props

        if self.qr_code_png is not None:
            result['QrCodePng'] = self.qr_code_png

        if self.reason is not None:
            result['Reason'] = self.reason

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.risk_verify_info is not None:
            result['RiskVerifyInfo'] = self.risk_verify_info.to_map()

        if self.secret is not None:
            result['Secret'] = self.secret

        if self.session_id is not None:
            result['SessionId'] = self.session_id

        if self.tenant_alias is not None:
            result['TenantAlias'] = self.tenant_alias

        if self.tenant_id is not None:
            result['TenantId'] = self.tenant_id

        result['TenantInfos'] = []
        if self.tenant_infos is not None:
            for k1 in self.tenant_infos:
                result['TenantInfos'].append(k1.to_map() if k1 else None)

        if self.vpc_region_id is not None:
            result['VpcRegionId'] = self.vpc_region_id

        if self.window_display_mode is not None:
            result['WindowDisplayMode'] = self.window_display_mode

        if self.wy_id is not None:
            result['WyId'] = self.wy_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessType') is not None:
            self.access_type = m.get('AccessType')

        if m.get('AccountType') is not None:
            self.account_type = m.get('AccountType')

        if m.get('AdDomain') is not None:
            self.ad_domain = m.get('AdDomain')

        if m.get('Email') is not None:
            self.email = m.get('Email')

        if m.get('EndUserId') is not None:
            self.end_user_id = m.get('EndUserId')

        if m.get('IdpId') is not None:
            self.idp_id = m.get('IdpId')

        if m.get('Industry') is not None:
            self.industry = m.get('Industry')

        if m.get('KeepAliveToken') is not None:
            self.keep_alive_token = m.get('KeepAliveToken')

        if m.get('Label') is not None:
            self.label = m.get('Label')

        if m.get('LoginToken') is not None:
            self.login_token = m.get('LoginToken')

        self.mfa_type_list = []
        if m.get('MfaTypeList') is not None:
            for k1 in m.get('MfaTypeList'):
                temp_model = main_models.GetLoginTokenResponseBodyMfaTypeList()
                self.mfa_type_list.append(temp_model.from_map(k1))

        if m.get('NextStage') is not None:
            self.next_stage = m.get('NextStage')

        if m.get('NickName') is not None:
            self.nick_name = m.get('NickName')

        if m.get('OfficeSites') is not None:
            self.office_sites = m.get('OfficeSites')

        if m.get('PasswordStrategy') is not None:
            temp_model = main_models.GetLoginTokenResponseBodyPasswordStrategy()
            self.password_strategy = temp_model.from_map(m.get('PasswordStrategy'))

        if m.get('Phone') is not None:
            self.phone = m.get('Phone')

        if m.get('Props') is not None:
            self.props = m.get('Props')

        if m.get('QrCodePng') is not None:
            self.qr_code_png = m.get('QrCodePng')

        if m.get('Reason') is not None:
            self.reason = m.get('Reason')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('RiskVerifyInfo') is not None:
            temp_model = main_models.GetLoginTokenResponseBodyRiskVerifyInfo()
            self.risk_verify_info = temp_model.from_map(m.get('RiskVerifyInfo'))

        if m.get('Secret') is not None:
            self.secret = m.get('Secret')

        if m.get('SessionId') is not None:
            self.session_id = m.get('SessionId')

        if m.get('TenantAlias') is not None:
            self.tenant_alias = m.get('TenantAlias')

        if m.get('TenantId') is not None:
            self.tenant_id = m.get('TenantId')

        self.tenant_infos = []
        if m.get('TenantInfos') is not None:
            for k1 in m.get('TenantInfos'):
                temp_model = main_models.GetLoginTokenResponseBodyTenantInfos()
                self.tenant_infos.append(temp_model.from_map(k1))

        if m.get('VpcRegionId') is not None:
            self.vpc_region_id = m.get('VpcRegionId')

        if m.get('WindowDisplayMode') is not None:
            self.window_display_mode = m.get('WindowDisplayMode')

        if m.get('WyId') is not None:
            self.wy_id = m.get('WyId')

        return self

class GetLoginTokenResponseBodyTenantInfos(DaraModel):
    def __init__(
        self,
        access_type: str = None,
        tenant_alias: str = None,
    ):
        self.access_type = access_type
        self.tenant_alias = tenant_alias

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_type is not None:
            result['AccessType'] = self.access_type

        if self.tenant_alias is not None:
            result['TenantAlias'] = self.tenant_alias

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessType') is not None:
            self.access_type = m.get('AccessType')

        if m.get('TenantAlias') is not None:
            self.tenant_alias = m.get('TenantAlias')

        return self

class GetLoginTokenResponseBodyRiskVerifyInfo(DaraModel):
    def __init__(
        self,
        email: str = None,
        last_lock_duration: int = None,
        locked: bool = None,
        phone: str = None,
    ):
        self.email = email
        self.last_lock_duration = last_lock_duration
        self.locked = locked
        self.phone = phone

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.email is not None:
            result['Email'] = self.email

        if self.last_lock_duration is not None:
            result['LastLockDuration'] = self.last_lock_duration

        if self.locked is not None:
            result['Locked'] = self.locked

        if self.phone is not None:
            result['Phone'] = self.phone

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Email') is not None:
            self.email = m.get('Email')

        if m.get('LastLockDuration') is not None:
            self.last_lock_duration = m.get('LastLockDuration')

        if m.get('Locked') is not None:
            self.locked = m.get('Locked')

        if m.get('Phone') is not None:
            self.phone = m.get('Phone')

        return self

class GetLoginTokenResponseBodyPasswordStrategy(DaraModel):
    def __init__(
        self,
        tenant_alternative_chars: List[str] = None,
        tenant_password_length: int = None,
    ):
        self.tenant_alternative_chars = tenant_alternative_chars
        self.tenant_password_length = tenant_password_length

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.tenant_alternative_chars is not None:
            result['TenantAlternativeChars'] = self.tenant_alternative_chars

        if self.tenant_password_length is not None:
            result['TenantPasswordLength'] = self.tenant_password_length

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('TenantAlternativeChars') is not None:
            self.tenant_alternative_chars = m.get('TenantAlternativeChars')

        if m.get('TenantPasswordLength') is not None:
            self.tenant_password_length = m.get('TenantPasswordLength')

        return self

class GetLoginTokenResponseBodyMfaTypeList(DaraModel):
    def __init__(
        self,
        name: str = None,
        stage: str = None,
    ):
        self.name = name
        self.stage = stage

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['Name'] = self.name

        if self.stage is not None:
            result['Stage'] = self.stage

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Stage') is not None:
            self.stage = m.get('Stage')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Dict

from alibabacloud_appstream_center20210220 import models as main_models
from alibabacloud_tea_openapi import utils_models as open_api_util_models
from alibabacloud_tea_openapi.client import Client as OpenApiClient
from alibabacloud_tea_openapi.utils import Utils
from darabonba.core import DaraCore as DaraCore
from darabonba.runtime import RuntimeOptions

"""
"""
class Client(OpenApiClient):

    def __init__(
        self,
        config: open_api_util_models.Config,
    ):
        super().__init__(config)
        self._endpoint_rule = ''
        self.check_config(config)
        self._endpoint = self.get_endpoint('appstream-center', self._region_id, self._endpoint_rule, self._network, self._suffix, self._endpoint_map, self._endpoint)

    def get_endpoint(
        self,
        product_id: str,
        region_id: str,
        endpoint_rule: str,
        network: str,
        suffix: str,
        endpoint_map: Dict[str, str],
        endpoint: str,
    ) -> str:
        if not DaraCore.is_null(endpoint):
            return endpoint
        if not DaraCore.is_null(endpoint_map) and not DaraCore.is_null(endpoint_map.get(region_id)):
            return endpoint_map.get(region_id)
        return Utils.get_endpoint_rules(product_id, region_id, endpoint_rule, network, suffix)

    def client_user_logout_with_options(
        self,
        request: main_models.ClientUserLogoutRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ClientUserLogoutResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.client_id):
            query['ClientId'] = request.client_id
        if not DaraCore.is_null(request.login_token):
            query['LoginToken'] = request.login_token
        if not DaraCore.is_null(request.office_site_id):
            query['OfficeSiteId'] = request.office_site_id
        if not DaraCore.is_null(request.profile_region):
            query['ProfileRegion'] = request.profile_region
        if not DaraCore.is_null(request.session_id):
            query['SessionId'] = request.session_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ClientUserLogout',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ClientUserLogoutResponse(),
            self.do_rpcrequest(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    async def client_user_logout_with_options_async(
        self,
        request: main_models.ClientUserLogoutRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ClientUserLogoutResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.client_id):
            query['ClientId'] = request.client_id
        if not DaraCore.is_null(request.login_token):
            query['LoginToken'] = request.login_token
        if not DaraCore.is_null(request.office_site_id):
            query['OfficeSiteId'] = request.office_site_id
        if not DaraCore.is_null(request.profile_region):
            query['ProfileRegion'] = request.profile_region
        if not DaraCore.is_null(request.session_id):
            query['SessionId'] = request.session_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ClientUserLogout',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ClientUserLogoutResponse(),
            await self.do_rpcrequest_async(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    def client_user_logout(
        self,
        request: main_models.ClientUserLogoutRequest,
    ) -> main_models.ClientUserLogoutResponse:
        runtime = RuntimeOptions()
        return self.client_user_logout_with_options(request, runtime)

    async def client_user_logout_async(
        self,
        request: main_models.ClientUserLogoutRequest,
    ) -> main_models.ClientUserLogoutResponse:
        runtime = RuntimeOptions()
        return await self.client_user_logout_with_options_async(request, runtime)

    def find_idp_list_by_login_identifier_with_options(
        self,
        tmp_req: main_models.FindIdpListByLoginIdentifierRequest,
        runtime: RuntimeOptions,
    ) -> main_models.FindIdpListByLoginIdentifierResponse:
        tmp_req.validate()
        request = main_models.FindIdpListByLoginIdentifierShrinkRequest()
        Utils.convert(tmp_req, request)
        if not DaraCore.is_null(tmp_req.available_features):
            request.available_features_shrink = Utils.array_to_string_with_specified_style(tmp_req.available_features, 'AvailableFeatures', 'json')
        query = {}
        if not DaraCore.is_null(request.available_features_shrink):
            query['AvailableFeatures'] = request.available_features_shrink
        if not DaraCore.is_null(request.client_ip):
            query['ClientIp'] = request.client_ip
        body = {}
        if not DaraCore.is_null(request.client_channel):
            body['ClientChannel'] = request.client_channel
        if not DaraCore.is_null(request.client_id):
            body['ClientId'] = request.client_id
        if not DaraCore.is_null(request.client_os):
            body['ClientOS'] = request.client_os
        if not DaraCore.is_null(request.client_version):
            body['ClientVersion'] = request.client_version
        if not DaraCore.is_null(request.login_identifier):
            body['LoginIdentifier'] = request.login_identifier
        if not DaraCore.is_null(request.support_types):
            body['SupportTypes'] = request.support_types
        if not DaraCore.is_null(request.uuid):
            body['Uuid'] = request.uuid
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query),
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'FindIdpListByLoginIdentifier',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.FindIdpListByLoginIdentifierResponse(),
            self.do_rpcrequest(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    async def find_idp_list_by_login_identifier_with_options_async(
        self,
        tmp_req: main_models.FindIdpListByLoginIdentifierRequest,
        runtime: RuntimeOptions,
    ) -> main_models.FindIdpListByLoginIdentifierResponse:
        tmp_req.validate()
        request = main_models.FindIdpListByLoginIdentifierShrinkRequest()
        Utils.convert(tmp_req, request)
        if not DaraCore.is_null(tmp_req.available_features):
            request.available_features_shrink = Utils.array_to_string_with_specified_style(tmp_req.available_features, 'AvailableFeatures', 'json')
        query = {}
        if not DaraCore.is_null(request.available_features_shrink):
            query['AvailableFeatures'] = request.available_features_shrink
        if not DaraCore.is_null(request.client_ip):
            query['ClientIp'] = request.client_ip
        body = {}
        if not DaraCore.is_null(request.client_channel):
            body['ClientChannel'] = request.client_channel
        if not DaraCore.is_null(request.client_id):
            body['ClientId'] = request.client_id
        if not DaraCore.is_null(request.client_os):
            body['ClientOS'] = request.client_os
        if not DaraCore.is_null(request.client_version):
            body['ClientVersion'] = request.client_version
        if not DaraCore.is_null(request.login_identifier):
            body['LoginIdentifier'] = request.login_identifier
        if not DaraCore.is_null(request.support_types):
            body['SupportTypes'] = request.support_types
        if not DaraCore.is_null(request.uuid):
            body['Uuid'] = request.uuid
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query),
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'FindIdpListByLoginIdentifier',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.FindIdpListByLoginIdentifierResponse(),
            await self.do_rpcrequest_async(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    def find_idp_list_by_login_identifier(
        self,
        request: main_models.FindIdpListByLoginIdentifierRequest,
    ) -> main_models.FindIdpListByLoginIdentifierResponse:
        runtime = RuntimeOptions()
        return self.find_idp_list_by_login_identifier_with_options(request, runtime)

    async def find_idp_list_by_login_identifier_async(
        self,
        request: main_models.FindIdpListByLoginIdentifierRequest,
    ) -> main_models.FindIdpListByLoginIdentifierResponse:
        runtime = RuntimeOptions()
        return await self.find_idp_list_by_login_identifier_with_options_async(request, runtime)

    def get_login_token_with_options(
        self,
        tmp_req: main_models.GetLoginTokenRequest,
        runtime: RuntimeOptions,
    ) -> main_models.GetLoginTokenResponse:
        tmp_req.validate()
        request = main_models.GetLoginTokenShrinkRequest()
        Utils.convert(tmp_req, request)
        if not DaraCore.is_null(tmp_req.available_features):
            request.available_features_shrink = Utils.array_to_string_with_specified_style(tmp_req.available_features, 'AvailableFeatures', 'json')
        query = {}
        if not DaraCore.is_null(request.area_site):
            query['AreaSite'] = request.area_site
        if not DaraCore.is_null(request.authentication_code):
            query['AuthenticationCode'] = request.authentication_code
        if not DaraCore.is_null(request.available_features_shrink):
            query['AvailableFeatures'] = request.available_features_shrink
        if not DaraCore.is_null(request.channel):
            query['Channel'] = request.channel
        if not DaraCore.is_null(request.client_id):
            query['ClientId'] = request.client_id
        if not DaraCore.is_null(request.client_name):
            query['ClientName'] = request.client_name
        if not DaraCore.is_null(request.client_os):
            query['ClientOS'] = request.client_os
        if not DaraCore.is_null(request.client_type):
            query['ClientType'] = request.client_type
        if not DaraCore.is_null(request.client_version):
            query['ClientVersion'] = request.client_version
        if not DaraCore.is_null(request.current_stage):
            query['CurrentStage'] = request.current_stage
        if not DaraCore.is_null(request.directory_id):
            query['DirectoryId'] = request.directory_id
        if not DaraCore.is_null(request.encrypted_finger_print_data):
            query['EncryptedFingerPrintData'] = request.encrypted_finger_print_data
        if not DaraCore.is_null(request.encrypted_key):
            query['EncryptedKey'] = request.encrypted_key
        if not DaraCore.is_null(request.encrypted_password):
            query['EncryptedPassword'] = request.encrypted_password
        if not DaraCore.is_null(request.end_user_id):
            query['EndUserId'] = request.end_user_id
        if not DaraCore.is_null(request.finger_print_data):
            query['FingerPrintData'] = request.finger_print_data
        if not DaraCore.is_null(request.idp_id):
            query['IdpId'] = request.idp_id
        if not DaraCore.is_null(request.image_url):
            query['ImageUrl'] = request.image_url
        if not DaraCore.is_null(request.keep_alive):
            query['KeepAlive'] = request.keep_alive
        if not DaraCore.is_null(request.keep_alive_token):
            query['KeepAliveToken'] = request.keep_alive_token
        if not DaraCore.is_null(request.login_identifier):
            query['LoginIdentifier'] = request.login_identifier
        if not DaraCore.is_null(request.login_name):
            query['LoginName'] = request.login_name
        if not DaraCore.is_null(request.mfa_type):
            query['MfaType'] = request.mfa_type
        if not DaraCore.is_null(request.network_type):
            query['NetworkType'] = request.network_type
        if not DaraCore.is_null(request.new_password):
            query['NewPassword'] = request.new_password
        if not DaraCore.is_null(request.office_site_id):
            query['OfficeSiteId'] = request.office_site_id
        if not DaraCore.is_null(request.old_password):
            query['OldPassword'] = request.old_password
        if not DaraCore.is_null(request.password):
            query['Password'] = request.password
        if not DaraCore.is_null(request.phone):
            query['Phone'] = request.phone
        if not DaraCore.is_null(request.phone_verify_code):
            query['PhoneVerifyCode'] = request.phone_verify_code
        if not DaraCore.is_null(request.profile_region):
            query['ProfileRegion'] = request.profile_region
        if not DaraCore.is_null(request.region_id):
            query['RegionId'] = request.region_id
        if not DaraCore.is_null(request.session_id):
            query['SessionId'] = request.session_id
        if not DaraCore.is_null(request.sso_extends_cookies):
            query['SsoExtendsCookies'] = request.sso_extends_cookies
        if not DaraCore.is_null(request.sso_session_token):
            query['SsoSessionToken'] = request.sso_session_token
        if not DaraCore.is_null(request.token_code):
            query['TokenCode'] = request.token_code
        if not DaraCore.is_null(request.umid_token):
            query['UmidToken'] = request.umid_token
        if not DaraCore.is_null(request.uuid):
            query['Uuid'] = request.uuid
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'GetLoginToken',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.GetLoginTokenResponse(),
            self.do_rpcrequest(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    async def get_login_token_with_options_async(
        self,
        tmp_req: main_models.GetLoginTokenRequest,
        runtime: RuntimeOptions,
    ) -> main_models.GetLoginTokenResponse:
        tmp_req.validate()
        request = main_models.GetLoginTokenShrinkRequest()
        Utils.convert(tmp_req, request)
        if not DaraCore.is_null(tmp_req.available_features):
            request.available_features_shrink = Utils.array_to_string_with_specified_style(tmp_req.available_features, 'AvailableFeatures', 'json')
        query = {}
        if not DaraCore.is_null(request.area_site):
            query['AreaSite'] = request.area_site
        if not DaraCore.is_null(request.authentication_code):
            query['AuthenticationCode'] = request.authentication_code
        if not DaraCore.is_null(request.available_features_shrink):
            query['AvailableFeatures'] = request.available_features_shrink
        if not DaraCore.is_null(request.channel):
            query['Channel'] = request.channel
        if not DaraCore.is_null(request.client_id):
            query['ClientId'] = request.client_id
        if not DaraCore.is_null(request.client_name):
            query['ClientName'] = request.client_name
        if not DaraCore.is_null(request.client_os):
            query['ClientOS'] = request.client_os
        if not DaraCore.is_null(request.client_type):
            query['ClientType'] = request.client_type
        if not DaraCore.is_null(request.client_version):
            query['ClientVersion'] = request.client_version
        if not DaraCore.is_null(request.current_stage):
            query['CurrentStage'] = request.current_stage
        if not DaraCore.is_null(request.directory_id):
            query['DirectoryId'] = request.directory_id
        if not DaraCore.is_null(request.encrypted_finger_print_data):
            query['EncryptedFingerPrintData'] = request.encrypted_finger_print_data
        if not DaraCore.is_null(request.encrypted_key):
            query['EncryptedKey'] = request.encrypted_key
        if not DaraCore.is_null(request.encrypted_password):
            query['EncryptedPassword'] = request.encrypted_password
        if not DaraCore.is_null(request.end_user_id):
            query['EndUserId'] = request.end_user_id
        if not DaraCore.is_null(request.finger_print_data):
            query['FingerPrintData'] = request.finger_print_data
        if not DaraCore.is_null(request.idp_id):
            query['IdpId'] = request.idp_id
        if not DaraCore.is_null(request.image_url):
            query['ImageUrl'] = request.image_url
        if not DaraCore.is_null(request.keep_alive):
            query['KeepAlive'] = request.keep_alive
        if not DaraCore.is_null(request.keep_alive_token):
            query['KeepAliveToken'] = request.keep_alive_token
        if not DaraCore.is_null(request.login_identifier):
            query['LoginIdentifier'] = request.login_identifier
        if not DaraCore.is_null(request.login_name):
            query['LoginName'] = request.login_name
        if not DaraCore.is_null(request.mfa_type):
            query['MfaType'] = request.mfa_type
        if not DaraCore.is_null(request.network_type):
            query['NetworkType'] = request.network_type
        if not DaraCore.is_null(request.new_password):
            query['NewPassword'] = request.new_password
        if not DaraCore.is_null(request.office_site_id):
            query['OfficeSiteId'] = request.office_site_id
        if not DaraCore.is_null(request.old_password):
            query['OldPassword'] = request.old_password
        if not DaraCore.is_null(request.password):
            query['Password'] = request.password
        if not DaraCore.is_null(request.phone):
            query['Phone'] = request.phone
        if not DaraCore.is_null(request.phone_verify_code):
            query['PhoneVerifyCode'] = request.phone_verify_code
        if not DaraCore.is_null(request.profile_region):
            query['ProfileRegion'] = request.profile_region
        if not DaraCore.is_null(request.region_id):
            query['RegionId'] = request.region_id
        if not DaraCore.is_null(request.session_id):
            query['SessionId'] = request.session_id
        if not DaraCore.is_null(request.sso_extends_cookies):
            query['SsoExtendsCookies'] = request.sso_extends_cookies
        if not DaraCore.is_null(request.sso_session_token):
            query['SsoSessionToken'] = request.sso_session_token
        if not DaraCore.is_null(request.token_code):
            query['TokenCode'] = request.token_code
        if not DaraCore.is_null(request.umid_token):
            query['UmidToken'] = request.umid_token
        if not DaraCore.is_null(request.uuid):
            query['Uuid'] = request.uuid
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'GetLoginToken',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.GetLoginTokenResponse(),
            await self.do_rpcrequest_async(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    def get_login_token(
        self,
        request: main_models.GetLoginTokenRequest,
    ) -> main_models.GetLoginTokenResponse:
        runtime = RuntimeOptions()
        return self.get_login_token_with_options(request, runtime)

    async def get_login_token_async(
        self,
        request: main_models.GetLoginTokenRequest,
    ) -> main_models.GetLoginTokenResponse:
        runtime = RuntimeOptions()
        return await self.get_login_token_with_options_async(request, runtime)

    def get_sts_token_with_options(
        self,
        request: main_models.GetStsTokenRequest,
        runtime: RuntimeOptions,
    ) -> main_models.GetStsTokenResponse:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.auth_code):
            body['AuthCode'] = request.auth_code
        if not DaraCore.is_null(request.client_id):
            body['ClientId'] = request.client_id
        if not DaraCore.is_null(request.client_ip):
            body['ClientIp'] = request.client_ip
        if not DaraCore.is_null(request.client_os):
            body['ClientOS'] = request.client_os
        if not DaraCore.is_null(request.client_version):
            body['ClientVersion'] = request.client_version
        if not DaraCore.is_null(request.uuid):
            body['Uuid'] = request.uuid
        req = open_api_util_models.OpenApiRequest(
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'GetStsToken',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.GetStsTokenResponse(),
            self.do_rpcrequest(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    async def get_sts_token_with_options_async(
        self,
        request: main_models.GetStsTokenRequest,
        runtime: RuntimeOptions,
    ) -> main_models.GetStsTokenResponse:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.auth_code):
            body['AuthCode'] = request.auth_code
        if not DaraCore.is_null(request.client_id):
            body['ClientId'] = request.client_id
        if not DaraCore.is_null(request.client_ip):
            body['ClientIp'] = request.client_ip
        if not DaraCore.is_null(request.client_os):
            body['ClientOS'] = request.client_os
        if not DaraCore.is_null(request.client_version):
            body['ClientVersion'] = request.client_version
        if not DaraCore.is_null(request.uuid):
            body['Uuid'] = request.uuid
        req = open_api_util_models.OpenApiRequest(
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'GetStsToken',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.GetStsTokenResponse(),
            await self.do_rpcrequest_async(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    def get_sts_token(
        self,
        request: main_models.GetStsTokenRequest,
    ) -> main_models.GetStsTokenResponse:
        runtime = RuntimeOptions()
        return self.get_sts_token_with_options(request, runtime)

    async def get_sts_token_async(
        self,
        request: main_models.GetStsTokenRequest,
    ) -> main_models.GetStsTokenResponse:
        runtime = RuntimeOptions()
        return await self.get_sts_token_with_options_async(request, runtime)

    def refresh_login_token_with_options(
        self,
        request: main_models.RefreshLoginTokenRequest,
        runtime: RuntimeOptions,
    ) -> main_models.RefreshLoginTokenResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.client_id):
            query['ClientId'] = request.client_id
        if not DaraCore.is_null(request.client_type):
            query['ClientType'] = request.client_type
        if not DaraCore.is_null(request.end_user_id):
            query['EndUserId'] = request.end_user_id
        if not DaraCore.is_null(request.login_identifier):
            query['LoginIdentifier'] = request.login_identifier
        if not DaraCore.is_null(request.login_token):
            query['LoginToken'] = request.login_token
        if not DaraCore.is_null(request.office_site_id):
            query['OfficeSiteId'] = request.office_site_id
        if not DaraCore.is_null(request.profile_region):
            query['ProfileRegion'] = request.profile_region
        if not DaraCore.is_null(request.session_id):
            query['SessionId'] = request.session_id
        if not DaraCore.is_null(request.uuid):
            query['Uuid'] = request.uuid
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RefreshLoginToken',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RefreshLoginTokenResponse(),
            self.do_rpcrequest(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    async def refresh_login_token_with_options_async(
        self,
        request: main_models.RefreshLoginTokenRequest,
        runtime: RuntimeOptions,
    ) -> main_models.RefreshLoginTokenResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.client_id):
            query['ClientId'] = request.client_id
        if not DaraCore.is_null(request.client_type):
            query['ClientType'] = request.client_type
        if not DaraCore.is_null(request.end_user_id):
            query['EndUserId'] = request.end_user_id
        if not DaraCore.is_null(request.login_identifier):
            query['LoginIdentifier'] = request.login_identifier
        if not DaraCore.is_null(request.login_token):
            query['LoginToken'] = request.login_token
        if not DaraCore.is_null(request.office_site_id):
            query['OfficeSiteId'] = request.office_site_id
        if not DaraCore.is_null(request.profile_region):
            query['ProfileRegion'] = request.profile_region
        if not DaraCore.is_null(request.session_id):
            query['SessionId'] = request.session_id
        if not DaraCore.is_null(request.uuid):
            query['Uuid'] = request.uuid
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RefreshLoginToken',
            version = '2021-02-20',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'Anonymous',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RefreshLoginTokenResponse(),
            await self.do_rpcrequest_async(params.action, params.version, params.protocol, params.method, params.auth_type, params.body_type, req, runtime)
        )

    def refresh_login_token(
        self,
        request: main_models.RefreshLoginTokenRequest,
    ) -> main_models.RefreshLoginTokenResponse:
        runtime = RuntimeOptions()
        return self.refresh_login_token_with_options(request, runtime)

    async def refresh_login_token_async(
        self,
        request: main_models.RefreshLoginTokenRequest,
    ) -> main_models.RefreshLoginTokenResponse:
        runtime = RuntimeOptions()
        return await self.refresh_login_token_with_options_async(request, runtime)



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_appstream_center20210220 import models as main_models
from darabonba.model import DaraModel

class GetStsTokenResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        sts_token_model: main_models.GetStsTokenResponseBodyStsTokenModel = None,
    ):
        self.request_id = request_id
        self.sts_token_model = sts_token_model

    def validate(self):
        if self.sts_token_model:
            self.sts_token_model.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.sts_token_model is not None:
            result['StsTokenModel'] = self.sts_token_model.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('StsTokenModel') is not None:
            temp_model = main_models.GetStsTokenResponseBodyStsTokenModel()
            self.sts_token_model = temp_model.from_map(m.get('StsTokenModel'))

        return self

class GetStsTokenResponseBodyStsTokenModel(DaraModel):
    def __init__(
        self,
        end_user_id: str = None,
        login_token: str = None,
        profile_region: str = None,
        session_id: str = None,
        sts_token: str = None,
        tenant_id: int = None,
    ):
        self.end_user_id = end_user_id
        self.login_token = login_token
        self.profile_region = profile_region
        self.session_id = session_id
        self.sts_token = sts_token
        self.tenant_id = tenant_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_user_id is not None:
            result['EndUserId'] = self.end_user_id

        if self.login_token is not None:
            result['LoginToken'] = self.login_token

        if self.profile_region is not None:
            result['ProfileRegion'] = self.profile_region

        if self.session_id is not None:
            result['SessionId'] = self.session_id

        if self.sts_token is not None:
            result['StsToken'] = self.sts_token

        if self.tenant_id is not None:
            result['TenantId'] = self.tenant_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndUserId') is not None:
            self.end_user_id = m.get('EndUserId')

        if m.get('LoginToken') is not None:
            self.login_token = m.get('LoginToken')

        if m.get('ProfileRegion') is not None:
            self.profile_region = m.get('ProfileRegion')

        if m.get('SessionId') is not None:
            self.session_id = m.get('SessionId')

        if m.get('StsToken') is not None:
            self.sts_token = m.get('StsToken')

        if m.get('TenantId') is not None:
            self.tenant_id = m.get('TenantId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ClientUserLogoutRequest(DaraModel):
    def __init__(
        self,
        client_id: str = None,
        login_token: str = None,
        office_site_id: str = None,
        profile_region: str = None,
        session_id: str = None,
    ):
        self.client_id = client_id
        self.login_token = login_token
        self.office_site_id = office_site_id
        self.profile_region = profile_region
        self.session_id = session_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_id is not None:
            result['ClientId'] = self.client_id

        if self.login_token is not None:
            result['LoginToken'] = self.login_token

        if self.office_site_id is not None:
            result['OfficeSiteId'] = self.office_site_id

        if self.profile_region is not None:
            result['ProfileRegion'] = self.profile_region

        if self.session_id is not None:
            result['SessionId'] = self.session_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ClientId') is not None:
            self.client_id = m.get('ClientId')

        if m.get('LoginToken') is not None:
            self.login_token = m.get('LoginToken')

        if m.get('OfficeSiteId') is not None:
            self.office_site_id = m.get('OfficeSiteId')

        if m.get('ProfileRegion') is not None:
            self.profile_region = m.get('ProfileRegion')

        if m.get('SessionId') is not None:
            self.session_id = m.get('SessionId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Dict

from darabonba.model import DaraModel

class GetLoginTokenRequest(DaraModel):
    def __init__(
        self,
        area_site: str = None,
        authentication_code: str = None,
        available_features: Dict[str, str] = None,
        channel: str = None,
        client_id: str = None,
        client_name: str = None,
        client_os: str = None,
        client_type: str = None,
        client_version: str = None,
        current_stage: str = None,
        directory_id: str = None,
        encrypted_finger_print_data: str = None,
        encrypted_key: str = None,
        encrypted_password: str = None,
        end_user_id: str = None,
        finger_print_data: str = None,
        idp_id: str = None,
        image_url: str = None,
        keep_alive: bool = None,
        keep_alive_token: str = None,
        login_identifier: str = None,
        login_name: str = None,
        mfa_type: str = None,
        network_type: str = None,
        new_password: str = None,
        office_site_id: str = None,
        old_password: str = None,
        password: str = None,
        phone: str = None,
        phone_verify_code: str = None,
        profile_region: str = None,
        region_id: str = None,
        session_id: str = None,
        sso_extends_cookies: str = None,
        sso_session_token: str = None,
        token_code: str = None,
        umid_token: str = None,
        uuid: str = None,
    ):
        self.area_site = area_site
        self.authentication_code = authentication_code
        self.available_features = available_features
        self.channel = channel
        # This parameter is required.
        self.client_id = client_id
        self.client_name = client_name
        self.client_os = client_os
        self.client_type = client_type
        self.client_version = client_version
        self.current_stage = current_stage
        self.directory_id = directory_id
        self.encrypted_finger_print_data = encrypted_finger_print_data
        self.encrypted_key = encrypted_key
        self.encrypted_password = encrypted_password
        self.end_user_id = end_user_id
        self.finger_print_data = finger_print_data
        self.idp_id = idp_id
        self.image_url = image_url
        self.keep_alive = keep_alive
        self.keep_alive_token = keep_alive_token
        self.login_identifier = login_identifier
        self.login_name = login_name
        self.mfa_type = mfa_type
        self.network_type = network_type
        self.new_password = new_password
        self.office_site_id = office_site_id
        self.old_password = old_password
        self.password = password
        self.phone = phone
        self.phone_verify_code = phone_verify_code
        self.profile_region = profile_region
        self.region_id = region_id
        self.session_id = session_id
        self.sso_extends_cookies = sso_extends_cookies
        self.sso_session_token = sso_session_token
        self.token_code = token_code
        self.umid_token = umid_token
        self.uuid = uuid

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.area_site is not None:
            result['AreaSite'] = self.area_site

        if self.authentication_code is not None:
            result['AuthenticationCode'] = self.authentication_code

        if self.available_features is not None:
            result['AvailableFeatures'] = self.available_features

        if self.channel is not None:
            result['Channel'] = self.channel

        if self.client_id is not None:
            result['ClientId'] = self.client_id

        if self.client_name is not None:
            result['ClientName'] = self.client_name

        if self.client_os is not None:
            result['ClientOS'] = self.client_os

        if self.client_type is not None:
            result['ClientType'] = self.client_type

        if self.client_version is not None:
            result['ClientVersion'] = self.client_version

        if self.current_stage is not None:
            result['CurrentStage'] = self.current_stage

        if self.directory_id is not None:
            result['DirectoryId'] = self.directory_id

        if self.encrypted_finger_print_data is not None:
            result['EncryptedFingerPrintData'] = self.encrypted_finger_print_data

        if self.encrypted_key is not None:
            result['EncryptedKey'] = self.encrypted_key

        if self.encrypted_password is not None:
            result['EncryptedPassword'] = self.encrypted_password

        if self.end_user_id is not None:
            result['EndUserId'] = self.end_user_id

        if self.finger_print_data is not None:
            result['FingerPrintData'] = self.finger_print_data

        if self.idp_id is not None:
            result['IdpId'] = self.idp_id

        if self.image_url is not None:
            result['ImageUrl'] = self.image_url

        if self.keep_alive is not None:
            result['KeepAlive'] = self.keep_alive

        if self.keep_alive_token is not None:
            result['KeepAliveToken'] = self.keep_alive_token

        if self.login_identifier is not None:
            result['LoginIdentifier'] = self.login_identifier

        if self.login_name is not None:
            result['LoginName'] = self.login_name

        if self.mfa_type is not None:
            result['MfaType'] = self.mfa_type

        if self.network_type is not None:
            result['NetworkType'] = self.network_type

        if self.new_password is not None:
            result['NewPassword'] = self.new_password

        if self.office_site_id is not None:
            result['OfficeSiteId'] = self.office_site_id

        if self.old_password is not None:
            result['OldPassword'] = self.old_password

        if self.password is not None:
            result['Password'] = self.password

        if self.phone is not None:
            result['Phone'] = self.phone

        if self.phone_verify_code is not None:
            result['PhoneVerifyCode'] = self.phone_verify_code

        if self.profile_region is not None:
            result['ProfileRegion'] = self.profile_region

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.session_id is not None:
            result['SessionId'] = self.session_id

        if self.sso_extends_cookies is not None:
            result['SsoExtendsCookies'] = self.sso_extends_cookies

        if self.sso_session_token is not None:
            result['SsoSessionToken'] = self.sso_session_token

        if self.token_code is not None:
            result['TokenCode'] = self.token_code

        if self.umid_token is not None:
            result['UmidToken'] = self.umid_token

        if self.uuid is not None:
            result['Uuid'] = self.uuid

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AreaSite') is not None:
            self.area_site = m.get('AreaSite')

        if m.get('AuthenticationCode') is not None:
            self.authentication_code = m.get('AuthenticationCode')

        if m.get('AvailableFeatures') is not None:
            self.available_features = m.get('AvailableFeatures')

        if m.get('Channel') is not None:
            self.channel = m.get('Channel')

        if m.get('ClientId') is not None:
            self.client_id = m.get('ClientId')

        if m.get('ClientName') is not None:
            self.client_name = m.get('ClientName')

        if m.get('ClientOS') is not None:
            self.client_os = m.get('ClientOS')

        if m.get('ClientType') is not None:
            self.client_type = m.get('ClientType')

        if m.get('ClientVersion') is not None:
            self.client_version = m.get('ClientVersion')

        if m.get('CurrentStage') is not None:
            self.current_stage = m.get('CurrentStage')

        if m.get('DirectoryId') is not None:
            self.directory_id = m.get('DirectoryId')

        if m.get('EncryptedFingerPrintData') is not None:
            self.encrypted_finger_print_data = m.get('EncryptedFingerPrintData')

        if m.get('EncryptedKey') is not None:
            self.encrypted_key = m.get('EncryptedKey')

        if m.get('EncryptedPassword') is not None:
            self.encrypted_password = m.get('EncryptedPassword')

        if m.get('EndUserId') is not None:
            self.end_user_id = m.get('EndUserId')

        if m.get('FingerPrintData') is not None:
            self.finger_print_data = m.get('FingerPrintData')

        if m.get('IdpId') is not None:
            self.idp_id = m.get('IdpId')

        if m.get('ImageUrl') is not None:
            self.image_url = m.get('ImageUrl')

        if m.get('KeepAlive') is not None:
            self.keep_alive = m.get('KeepAlive')

        if m.get('KeepAliveToken') is not None:
            self.keep_alive_token = m.get('KeepAliveToken')

        if m.get('LoginIdentifier') is not None:
            self.login_identifier = m.get('LoginIdentifier')

        if m.get('LoginName') is not None:
            self.login_name = m.get('LoginName')

        if m.get('MfaType') is not None:
            self.mfa_type = m.get('MfaType')

        if m.get('NetworkType') is not None:
            self.network_type = m.get('NetworkType')

        if m.get('NewPassword') is not None:
            self.new_password = m.get('NewPassword')

        if m.get('OfficeSiteId') is not None:
            self.office_site_id = m.get('OfficeSiteId')

        if m.get('OldPassword') is not None:
            self.old_password = m.get('OldPassword')

        if m.get('Password') is not None:
            self.password = m.get('Password')

        if m.get('Phone') is not None:
            self.phone = m.get('Phone')

        if m.get('PhoneVerifyCode') is not None:
            self.phone_verify_code = m.get('PhoneVerifyCode')

        if m.get('ProfileRegion') is not None:
            self.profile_region = m.get('ProfileRegion')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('SessionId') is not None:
            self.session_id = m.get('SessionId')

        if m.get('SsoExtendsCookies') is not None:
            self.sso_extends_cookies = m.get('SsoExtendsCookies')

        if m.get('SsoSessionToken') is not None:
            self.sso_session_token = m.get('SsoSessionToken')

        if m.get('TokenCode') is not None:
            self.token_code = m.get('TokenCode')

        if m.get('UmidToken') is not None:
            self.umid_token = m.get('UmidToken')

        if m.get('Uuid') is not None:
            self.uuid = m.get('Uuid')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Dict

from alibabacloud_appstream_center20210220 import models as main_models
from darabonba.model import DaraModel

class FindIdpListByLoginIdentifierResponseBody(DaraModel):
    def __init__(
        self,
        idp_infos: List[main_models.FindIdpListByLoginIdentifierResponseBodyIdpInfos] = None,
        office_site_info: main_models.FindIdpListByLoginIdentifierResponseBodyOfficeSiteInfo = None,
        pop_region_config: Dict[str, str] = None,
        profile_region: str = None,
        request_id: str = None,
        tenant_alias_info: main_models.FindIdpListByLoginIdentifierResponseBodyTenantAliasInfo = None,
    ):
        self.idp_infos = idp_infos
        self.office_site_info = office_site_info
        self.pop_region_config = pop_region_config
        self.profile_region = profile_region
        self.request_id = request_id
        self.tenant_alias_info = tenant_alias_info

    def validate(self):
        if self.idp_infos:
            for v1 in self.idp_infos:
                 if v1:
                    v1.validate()
        if self.office_site_info:
            self.office_site_info.validate()
        if self.tenant_alias_info:
            self.tenant_alias_info.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['IdpInfos'] = []
        if self.idp_infos is not None:
            for k1 in self.idp_infos:
                result['IdpInfos'].append(k1.to_map() if k1 else None)

        if self.office_site_info is not None:
            result['OfficeSiteInfo'] = self.office_site_info.to_map()

        if self.pop_region_config is not None:
            result['PopRegionConfig'] = self.pop_region_config

        if self.profile_region is not None:
            result['ProfileRegion'] = self.profile_region

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.tenant_alias_info is not None:
            result['TenantAliasInfo'] = self.tenant_alias_info.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.idp_infos = []
        if m.get('IdpInfos') is not None:
            for k1 in m.get('IdpInfos'):
                temp_model = main_models.FindIdpListByLoginIdentifierResponseBodyIdpInfos()
                self.idp_infos.append(temp_model.from_map(k1))

        if m.get('OfficeSiteInfo') is not None:
            temp_model = main_models.FindIdpListByLoginIdentifierResponseBodyOfficeSiteInfo()
            self.office_site_info = temp_model.from_map(m.get('OfficeSiteInfo'))

        if m.get('PopRegionConfig') is not None:
            self.pop_region_config = m.get('PopRegionConfig')

        if m.get('ProfileRegion') is not None:
            self.profile_region = m.get('ProfileRegion')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TenantAliasInfo') is not None:
            temp_model = main_models.FindIdpListByLoginIdentifierResponseBodyTenantAliasInfo()
            self.tenant_alias_info = temp_model.from_map(m.get('TenantAliasInfo'))

        return self

class FindIdpListByLoginIdentifierResponseBodyTenantAliasInfo(DaraModel):
    def __init__(
        self,
        access_type: str = None,
        prefer_vpc_access: bool = None,
        tenant_alias: str = None,
        vpc_access_address: str = None,
    ):
        self.access_type = access_type
        self.prefer_vpc_access = prefer_vpc_access
        self.tenant_alias = tenant_alias
        self.vpc_access_address = vpc_access_address

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_type is not None:
            result['AccessType'] = self.access_type

        if self.prefer_vpc_access is not None:
            result['PreferVpcAccess'] = self.prefer_vpc_access

        if self.tenant_alias is not None:
            result['TenantAlias'] = self.tenant_alias

        if self.vpc_access_address is not None:
            result['VpcAccessAddress'] = self.vpc_access_address

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessType') is not None:
            self.access_type = m.get('AccessType')

        if m.get('PreferVpcAccess') is not None:
            self.prefer_vpc_access = m.get('PreferVpcAccess')

        if m.get('TenantAlias') is not None:
            self.tenant_alias = m.get('TenantAlias')

        if m.get('VpcAccessAddress') is not None:
            self.vpc_access_address = m.get('VpcAccessAddress')

        return self

class FindIdpListByLoginIdentifierResponseBodyOfficeSiteInfo(DaraModel):
    def __init__(
        self,
        access_type: str = None,
        office_site_id: str = None,
        prefer_vpc_access: bool = None,
        provider_id: str = None,
        region_id: str = None,
        sso_service_url: str = None,
        vpc_access_address: str = None,
    ):
        self.access_type = access_type
        self.office_site_id = office_site_id
        self.prefer_vpc_access = prefer_vpc_access
        self.provider_id = provider_id
        self.region_id = region_id
        self.sso_service_url = sso_service_url
        self.vpc_access_address = vpc_access_address

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_type is not None:
            result['AccessType'] = self.access_type

        if self.office_site_id is not None:
            result['OfficeSiteId'] = self.office_site_id

        if self.prefer_vpc_access is not None:
            result['PreferVpcAccess'] = self.prefer_vpc_access

        if self.provider_id is not None:
            result['ProviderId'] = self.provider_id

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.sso_service_url is not None:
            result['SsoServiceUrl'] = self.sso_service_url

        if self.vpc_access_address is not None:
            result['VpcAccessAddress'] = self.vpc_access_address

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessType') is not None:
            self.access_type = m.get('AccessType')

        if m.get('OfficeSiteId') is not None:
            self.office_site_id = m.get('OfficeSiteId')

        if m.get('PreferVpcAccess') is not None:
            self.prefer_vpc_access = m.get('PreferVpcAccess')

        if m.get('ProviderId') is not None:
            self.provider_id = m.get('ProviderId')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('SsoServiceUrl') is not None:
            self.sso_service_url = m.get('SsoServiceUrl')

        if m.get('VpcAccessAddress') is not None:
            self.vpc_access_address = m.get('VpcAccessAddress')

        return self



class FindIdpListByLoginIdentifierResponseBodyIdpInfos(DaraModel):
    def __init__(
        self,
        account_type: str = None,
        cookies: str = None,
        idp_id: str = None,
        idp_name: str = None,
        idp_name_en: str = None,
        idp_provider: str = None,
        jump_switch: str = None,
        sso_protocol: str = None,
        sso_service_url: str = None,
    ):
        self.account_type = account_type
        self.cookies = cookies
        self.idp_id = idp_id
        self.idp_name = idp_name
        self.idp_name_en = idp_name_en
        self.idp_provider = idp_provider
        self.jump_switch = jump_switch
        self.sso_protocol = sso_protocol
        self.sso_service_url = sso_service_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.account_type is not None:
            result['AccountType'] = self.account_type

        if self.cookies is not None:
            result['Cookies'] = self.cookies

        if self.idp_id is not None:
            result['IdpId'] = self.idp_id

        if self.idp_name is not None:
            result['IdpName'] = self.idp_name

        if self.idp_name_en is not None:
            result['IdpNameEN'] = self.idp_name_en

        if self.idp_provider is not None:
            result['IdpProvider'] = self.idp_provider

        if self.jump_switch is not None:
            result['JumpSwitch'] = self.jump_switch

        if self.sso_protocol is not None:
            result['SsoProtocol'] = self.sso_protocol

        if self.sso_service_url is not None:
            result['SsoServiceUrl'] = self.sso_service_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccountType') is not None:
            self.account_type = m.get('AccountType')

        if m.get('Cookies') is not None:
            self.cookies = m.get('Cookies')

        if m.get('IdpId') is not None:
            self.idp_id = m.get('IdpId')

        if m.get('IdpName') is not None:
            self.idp_name = m.get('IdpName')

        if m.get('IdpNameEN') is not None:
            self.idp_name_en = m.get('IdpNameEN')

        if m.get('IdpProvider') is not None:
            self.idp_provider = m.get('IdpProvider')

        if m.get('JumpSwitch') is not None:
            self.jump_switch = m.get('JumpSwitch')

        if m.get('SsoProtocol') is not None:
            self.sso_protocol = m.get('SsoProtocol')

        if m.get('SsoServiceUrl') is not None:
            self.sso_service_url = m.get('SsoServiceUrl')

        return self

